Documentation
¶
Index ¶
- func Create(name string, email string, expires string, callback string, ...) (respBody []byte, err error)
- func CreateKey(developerEmail string, appID string, consumerKey string, consumerSecret string, ...) (respBody []byte, err error)
- func Delete(name string, developerID string) (respBody []byte, err error)
- func DeleteKey(developerEmail string, appName string, key string) (respBody []byte, err error)
- func Export(conn int) (payload [][]byte, err error)
- func GenerateKey(name string, developerID string, apiProducts []string, callback string, ...) (respBody []byte, err error)
- func Get(appID string) (respBody []byte, err error)
- func GetKey(developerEmail string, appID string, key string) (respBody []byte, err error)
- func Import(conn int, filePath string, developersFilePath string) error
- func List(includeCred bool, expand bool, count int) (respBody []byte, err error)
- func ListApps(productName string) (respBody []byte, err error)
- func Manage(appID string, developerEmail string, action string) (respBody []byte, err error)
- func ManageKey(developerEmail string, appID string, consumerKey string, action string) (respBody []byte, err error)
- func SearchApp(name string) (respBody []byte, err error)
- func UpdateKey(developerEmail string, appID string, consumerKey string, consumerSecret string, ...) (respBody []byte, err error)
- func UpdateKeyProducts(developerEmail string, appID string, consumerKey string, apiProducts []string) (respBody []byte, err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Create ¶
func Create(name string, email string, expires string, callback string, apiProducts []string, scopes []string, attrs map[string]string) (respBody []byte, err error)
Create
func CreateKey ¶
func CreateKey(developerEmail string, appID string, consumerKey string, consumerSecret string, apiProducts []string, scopes []string, attrs map[string]string) (respBody []byte, err error)
CreateKey
func GenerateKey ¶
func GenerateKey(name string, developerID string, apiProducts []string, callback string, expires string, scopes []string) (respBody []byte, err error)
GenerateKey
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.